==> huaweicloudsdkeip-3.1.108-py2.py3-none-any.whl: huaweicloudsdkeip/v3/model/detach_batch_public_ip_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DetachBatchPublicIpResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'publicips': 'list[BatchPublicipResp]',
        'request_id': 'str'
    }

    attribute_map = {
        'publicips': 'publicips',
        'request_id': 'request_id'
    }

    def __init__(self, publicips=None, request_id=None):
        """DetachBatchPublicIpResponse

        The model defined in huaweicloud sdk

        :param publicips: 弹性公网IP对象
        :type publicips: list[:class:`huaweicloudsdkeip.v3.BatchPublicipResp`]
        :param request_id: 本次请求编号
        :type request_id: str
        """
        
        super(DetachBatchPublicIpResponse, self).__init__()

        self._publicips = None
        self._request_id = None
        self.discriminator = None

        if publicips is not None:
            self.publicips = publicips
        if request_id is not None:
            self.request_id = request_id

    @property
    def publicips(self):
        """Gets the publicips of this DetachBatchPublicIpResponse.

        弹性公网IP对象

        :return: The publicips of this DetachBatchPublicIpResponse.
        :rtype: list[:class:`huaweicloudsdkeip.v3.BatchPublicipResp`]
        """
        return self._publicips

    @publicips.setter
    def publicips(self, publicips):
        """Sets the publicips of this DetachBatchPublicIpResponse.

        弹性公网IP对象

        :param publicips: The publicips of this DetachBatchPublicIpResponse.
        :type publicips: list[:class:`huaweicloudsdkeip.v3.BatchPublicipResp`]
        """
        self._publicips = publicips

    @property
    def request_id(self):
        """Gets the request_id of this DetachBatchPublicIpResponse.

        本次请求编号

        :return: The request_id of this DetachBatchPublicIpResponse.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this DetachBatchPublicIpResponse.

        本次请求编号

        :param request_id: The request_id of this DetachBatchPublicIpResponse.
        :type request_id: str
        """
        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetachBatchPublicIpResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeip-3.1.145-py2.py3-none-any.whl: huaweicloudsdkeip/v3/model/detach_batch_public_ip_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DetachBatchPublicIpResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'publicips': 'list[BatchPublicipResp]',
        'request_id': 'str'
    }

    attribute_map = {
        'publicips': 'publicips',
        'request_id': 'request_id'
    }

    def __init__(self, publicips=None, request_id=None):
        r"""DetachBatchPublicIpResponse

        The model defined in huaweicloud sdk

        :param publicips: 弹性公网IP对象
        :type publicips: list[:class:`huaweicloudsdkeip.v3.BatchPublicipResp`]
        :param request_id: 本次请求编号
        :type request_id: str
        """
        
        super(DetachBatchPublicIpResponse, self).__init__()

        self._publicips = None
        self._request_id = None
        self.discriminator = None

        if publicips is not None:
            self.publicips = publicips
        if request_id is not None:
            self.request_id = request_id

    @property
    def publicips(self):
        r"""Gets the publicips of this DetachBatchPublicIpResponse.

        弹性公网IP对象

        :return: The publicips of this DetachBatchPublicIpResponse.
        :rtype: list[:class:`huaweicloudsdkeip.v3.BatchPublicipResp`]
        """
        return self._publicips

    @publicips.setter
    def publicips(self, publicips):
        r"""Sets the publicips of this DetachBatchPublicIpResponse.

        弹性公网IP对象

        :param publicips: The publicips of this DetachBatchPublicIpResponse.
        :type publicips: list[:class:`huaweicloudsdkeip.v3.BatchPublicipResp`]
        """
        self._publicips = publicips

    @property
    def request_id(self):
        r"""Gets the request_id of this DetachBatchPublicIpResponse.

        本次请求编号

        :return: The request_id of this DetachBatchPublicIpResponse.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        r"""Sets the request_id of this DetachBatchPublicIpResponse.

        本次请求编号

        :param request_id: The request_id of this DetachBatchPublicIpResponse.
        :type request_id: str
        """
        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetachBatchPublicIpResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
